@@ -20,6 +20,7 @@ class Bid(OptimizationObject):
     def __init__(self,
             polynomial='10P',
             bid_points=None,
+            constant_term=0,
             owner=None,
             times=None,
             input_variable=0,
@@ -64,7 +65,9 @@ class Bid(OptimizationObject):
                 # just the input->output points mapping in this case  - see coopr/examples/pyomo/piecewise/example3.py
                 return mapping[input_var]
                 
-            pw_representation=Piecewise(self.times.set,self.output(),self.input_variable(),
+            pw_representation=Piecewise(self.times.set,
+                                          self.get_variable('cost',time=None,indexed=True),
+                                          self.input_variable(),
                                           pw_pts=in_pts,
                                           pw_constr_type='LB',
                                           pw_repn='DCC', # the disagregated convex combination method 
@@ -82,14 +85,22 @@ class Bid(OptimizationObject):
                 out = value(self.status_variable(time))*self.polynomial[0]+self.polynomial[1]*value(self.input_variable(time))
             else:
                 out = self.status_variable(time)*self.polynomial[0]+self.polynomial[1]*self.input_variable(time)
-        else: out=self.get_variable('cost',time=time,indexed=True)
-        return out if not evaluate else value(out)                        
+        else: 
+            out = self.get_variable('cost',time=time,indexed=True)
+            if evaluate: out = value(out)
+        
+        if self.is_pwl and self.constant_term!=0:
+            status = self.status_variable(time)
+            if evaluate: status=value(status) 
+            out += status*self.constant_term
+            
+        return out
     def output_true(self,input_var): 
         '''true output value of bid'''
         input_val = value(input_var)
         if self.is_pwl:
             for A,B in pairwise(self.bid_points):
-                if A[0]<=input_val<=B[0]: return get_line_value(A, B, input_val)
+                if A[0]<=input_val<=B[0]: return get_line_value(A, B, input_val) + self.constant_term
         else: 
             return polynomial_value(self.polynomial, input_val)
     def output_incremental(self,input_var):
@@ -197,4 +208,4 @@ def get_line_value(A,B,x):
     # see http://bit.ly/Pd4z4l
     xA,yA = A
     slope = get_line_slope(A,B)
-    return slope*(value(x) - xA) + yA
\ No newline at end of file
+    return slope*(value(x) - xA) + yA
