@@ -9,6 +9,12 @@ import itertools,operator
 import datetime
 from dateutil import parser
 
+try: # for development
+    from pdb import set_trace as debug #pudb
+except: pass 
+
+def bool_to_int(x): return 1 if x else 0
+
 ###### matrix stuff #######
 def getColumn(matrix,colNum): return [row[colNum] for row in matrix]#equiv to matrix(:,j)
 def elementwiseMultiply(La,Lb): return map(operator.mul, La,Lb)
@@ -244,4 +250,4 @@ def show_memory_refs(name):
     objgraph.show_chain(objgraph.find_backref_chain( obj , inspect.ismodule),filename='chain-{}.png'.format(name))
 def show_memory_growth():
     import objgraph
-    objgraph.show_growth()
\ No newline at end of file
+    objgraph.show_growth()
